/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.server.security;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.apache.druid.query.policy.Policy;

import javax.annotation.Nullable;

public class AllowAllAuthorizer implements Authorizer
{
  @Nullable
  private final Policy policy;

  @JsonCreator
  public AllowAllAuthorizer(
      @JsonProperty("policy") @Nullable Policy policy
  )
  {
    this.policy = policy;
  }

  @Override
  public Access authorize(AuthenticationResult authenticationResult, Resource resource, Action action)
  {
    if (shouldApplyPolicy(resource, action)) {
      return Access.allowWithRestriction(policy);
    }
    return Access.OK;
  }

  private boolean shouldApplyPolicy(Resource resource, Action action)
  {
    return policy != null && AuthorizationUtils.shouldApplyPolicy(resource, action);
  }
}
